@@ -32,37 +32,56 @@ class Game:
 class NetworkFeedback:
     """Template class for feedback from a network game selector"""
     
-    def setServer(self, server):
-        """Set the server.
-        """
+    def setProfile(self, profile):
         pass
     
-    def sendCommand(self, command):
-        """
-        """
+    def joinRoom(self, room):
         pass
     
-    def answerAdvert(self, advert):
-        """
-        """
-        pass
-
-    def acceptGame(self):
-        """Accept the last requested game."""
-        pass
-    
-    def declineGame(self):
-        """Decline the last requested game."""
+    def joinTable(self, table):
         pass
     
 class NetworkController:
     """"""
     
+    def addProfile(self, profile, name):
+        pass
+    
     def addChat(self, user, channel, text):
         """Add chat 
         """
         pass
     
+    def addRoom(self, index, name, description, room):
+        """Add a game room.
+        
+        'name' is the name of the room (string).
+        'description' is a description of the room (string).
+        'room' is the room to add (user-defined)
+        """
+        pass
+    
+    def removeRoom(self, room):
+        pass
+    
+    def addTable(self, name, table):
+        pass
+
+    def removeTable(self, table):
+        pass
+    
+    def clearTables(self):
+        pass
+    
+    def addPlayer(self, name, player):
+        pass
+    
+    def removePlayer(self, player):
+        pass
+    
+    def clearPlayers(self):
+        pass
+
     def addAdvert(self, title, rating, advert):
         """Add a game advert.
         
@@ -85,6 +104,9 @@ class NetworkController:
         'gameName' is the name of the game this player requested to join (string).
         """
         pass
+    
+    def close(self):
+        pass
 
 class ViewFeedback:
     """Template class for feedback from a view object"""
@@ -238,12 +260,21 @@ class UIFeedback:
     def onReadFileDescriptor(self, fd):
         """Called when a file descriptor is able to be read.
         
-        'fds' is the file descriptor with available data to read (integer).
+        'fd' is the file descriptor with available data to read (integer).
         
         Return False when finished otherwise True.
         """
-        pass
+        return False
 
+    def onWriteFileDescriptor(self, fd):
+        """Called when a file descriptor can be written to.
+        
+        'fd' is the file descriptor that can be written to (integer).
+        
+        Return False if writing is completed otherwise True
+        """
+        return False
+    
     def onGameStart(self, game):
         """Called when a local game is started.
         
@@ -332,6 +363,15 @@ class UI:
         """
         pass
     
+    def writeFileDescriptor(self, fd):
+        """Notify when a file descriptor can be written to.
+        
+        'fd' is the file descriptor to write (integer).
+        
+        When data can be written onWriteFileDescriptor is called.
+        """
+        pass
+    
     def addTimer(self, feedback, duration):
         """Add a timer.
         
@@ -395,4 +435,4 @@ class UI:
         
     def close(self):
         """Report the application has ended"""
-        pass
\ No newline at end of file
+        pass
