@@ -18,6 +18,14 @@
 #define R_GTOTAL (SCOREROWS-1)
 #define R_LTOTAL (R_GTOTAL-1)
 
+#define KEY_NUMBER_OF_COMPUTERS       "NumberOfComputerOpponents"
+#define KEY_NUMBER_OF_HUMANS          "NumberOfHumanOpponents"
+#define KEY_GAME_TYPE                 "GameType"
+#define KEY_NUMTRIALS                 "MonteCarloTrials"
+#define KEY_DELAY_BETWEEN_ROLLS       "DelayBetweenRolls"
+#define KEY_DISPLAY_COMPUTER_THOUGHTS "DisplayComputerThoughts"
+#define KEY_PLAYER_NAMES              "PlayerNames"
+
 /* clist.c */
 extern GtkWidget *create_score_list (void);
 extern void setup_score_list (GtkWidget * scorelist);
@@ -31,6 +39,9 @@ extern void score_list_set_column_title (GtkWidget * scorelist, int column,
 /* setup.c */
 extern gint setup_game (GtkAction * action, gpointer data);
 extern void GRenamePlayer (gint playerno);
+extern GameType game_type_from_string(const gchar *string);
+extern GameType get_new_game_type(void);
+extern void set_new_game_type(GameType type);
 
 /* gyahtzee.c */
 extern int GyahtzeeAbort;
